@@ -16,6 +16,8 @@ from waitress.server import create_server
 
 sys.path.append(os.path.join(os.path.dirname(__file__), "..", ".."))
 
+from flask_cors import CORS
+
 from decentra_network.accounts.get_balance import GetBalance
 from decentra_network.blockchain.block.create_block import CreateBlock
 from decentra_network.blockchain.block.get_block import GetBlock
@@ -48,6 +50,15 @@ from decentra_network.wallet.wallet_selector import wallet_selector
 logger = get_logger("API")
 
 app = Flask(__name__)
+CORS(app,
+     resources={
+         r"/export/block/*": {
+             "origins": "*"
+         },
+         r"/status": {
+             "origins": "*"
+         }
+     })
 
 custom_block = None
 custom_current_time = None
@@ -163,8 +174,8 @@ def balance_wallets_page():
                                0) if custom_wallet is None else custom_wallet
     the_block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
                  if custom_block is None else custom_block)
-    return jsonify(GetBalance(the_block, the_wallet,
-                              account_list=account_list))
+    return jsonify(
+        GetBalance(the_wallet, account_list=account_list, block=the_block))
 
 
 @app.route("/node/start/<ip>/<port>", methods=["GET"])
@@ -382,6 +393,15 @@ def proof_check_page():
         ))
 
 
+@app.route("/export/block/json", methods=["GET"])
+def export_block_json_page():
+    logger.info(
+        f"{request.remote_addr} {request.method} {request.url} {request.data}")
+    the_block = (GetBlock(custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH)
+                 if custom_block is None else custom_block)
+    return jsonify(the_block.dump_json())
+
+
 @app.errorhandler(500)
 def handle_exception(e):
     logger.exception(f"500: {e}")
