@@ -13,7 +13,15 @@ logger = get_logger("CONSENSUS_FIRST_ROUND")
 
 def candidate_blocks_check(candidate_class: candidate_block,
                            unl_nodes: dict) -> bool:
-    if len(candidate_class.candidate_blocks) >= ((len(unl_nodes) * 80) / 100):
+    logger.info("Candidate block control started for round 2")
+    logger.debug(
+        f"len(candidate_class.candidate_blocks): {len(candidate_class.candidate_blocks)}"
+    )
+    logger.debug(f"len(unl_nodes): {len(unl_nodes)}")
+    if len(candidate_class.candidate_blocks) > ((
+        (len(unl_nodes) + 1) * 50) / 100):
+        logger.info("Candidate block number is True")
         return True
     else:
+        logger.info("Candidate block number is not True")
         return False
