@@ -16,11 +16,25 @@ from decentra_network.lib.log import get_logger
 logger = get_logger("CONSENSUS_FIRST_ROUND")
 
 
-def round_check(block: Block, candidate_class: candidate_block,
-                unl_nodes: dict) -> bool:
+def round_check(
+    block: Block, 
+    candidate_class: candidate_block,
+    unl_nodes: dict,
+    custom_TEMP_ACCOUNTS_PATH: str = None,
+    custom_TEMP_BLOCK_PATH: str = None,
+    custom_TEMP_BLOCKSHASH_PATH: str = None,
+    custom_TEMP_BLOCKSHASH_PART_PATH: str = None,    
+    ) -> bool:
+    logger.info("Round 1 checking is started")
+    if not time_difference_check(
+        block=block,
+        custom_TEMP_BLOCK_PATH=custom_TEMP_BLOCK_PATH,
+        custom_TEMP_ACCOUNTS_PATH=custom_TEMP_ACCOUNTS_PATH,
+        custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
+        custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,           
+        ):
+        return False    
     if not candidate_blocks_check(candidate_class, unl_nodes):
         return False
-    if not time_difference_check(block=block):
-        return False
-
+    logger.info("Round 1 checking is True")
     return True
