@@ -37,22 +37,23 @@ def consensus_round_2(
     At this stage of the consensus process,
     The blocks (block hashes) of our and the
     unl nodes are compared and the block accepted
-    by 80 percent is approved.
+    by majority approving.
 
     Inputs:
       * block: The block (class) we want consensus
       round 2 to be done
     """
 
-    logger.debug(
-        f"BLOCK#{block.sequance_number}:{block.empty_block_number} Second round is starting"
+    logger.info(
+        f"BLOCK#{block.sequence_number}:{block.empty_block_number} second round is starting"
     )
 
     unl_nodes = Unl.get_unl_nodes() if unl_nodes is None else unl_nodes
-    candidate_class = (GetCandidateBlocks()
+    candidate_class = (GetCandidateBlocks(block=block)
                        if candidate_class is None else candidate_class)
+    logger.debug(f"unl_nodes: {unl_nodes}")
+    logger.debug(f"candidate_class: {candidate_class.__dict__}")
 
-    result = None
     if round_check(block, candidate_class, unl_nodes):
         round_process(
             block,
@@ -65,12 +66,10 @@ def consensus_round_2(
             custom_TEMP_BLOCKSHASH_PATH=custom_TEMP_BLOCKSHASH_PATH,
             custom_TEMP_BLOCKSHASH_PART_PATH=custom_TEMP_BLOCKSHASH_PART_PATH,
         )
-        result = True
+        
+        logger.info("Round 2 check is True")
+        return True
     else:
-        logger.debug("Our block hash is sending to the unl nodes")
-        the_server = server.Server if custom_server is None else custom_server
-        the_server.send_my_block_hash(block)
-        result = False
+        logger.warning("Round 2 check is False")
+        return False
 
-    logger.debug("Second round is done")
-    return result
