@@ -59,12 +59,12 @@ class WalletBox(MDGridLayout):
                         text="CANCEL",
                         on_press=self.dismiss_wallet_alert_dialog,
                         font_size="18sp",
-                        font_name=f"{self.FONT_PATH}RobotoCondensed-Bold",
+                        font_name=f"{self.FONT_PATH}Poppins-Bold",
                     ),
                     MDFlatButton(
                         text="OK",
                         font_size="18sp",
-                        font_name=f"{self.FONT_PATH}RobotoCondensed-Bold",
+                        font_name=f"{self.FONT_PATH}Poppins-Bold",
                         on_press=self.create_the_wallet,
                     ),
                 ],
@@ -128,12 +128,12 @@ class WalletBox(MDGridLayout):
                         text="CANCEL",
                         on_press=self.dismiss_delete_wallet_alert_dialog,
                         font_size="18sp",
-                        font_name=f"{self.FONT_PATH}RobotoCondensed-Bold",
+                        font_name=f"{self.FONT_PATH}Poppins-Bold",
                     ),
                     MDFlatButton(
                         text="OK",
                         font_size="18sp",
-                        font_name=f"{self.FONT_PATH}RobotoCondensed-Bold",
+                        font_name=f"{self.FONT_PATH}Poppins-Bold",
                         on_press=self.delete_the_wallet,
                     ),
                 ],
