@@ -4,6 +4,8 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
+import contextlib
+import json
 from threading import Event, Thread, Timer
 
 
@@ -29,4 +31,5 @@ class perpetualTimer(Timer):
 
     def run(self):
         while not self.finished.wait(self.interval):
-            self.function(*self.args, **self.kwargs)
\ No newline at end of file
+            with contextlib.suppress(json.decoder.JSONDecodeError):
+                self.function(*self.args, **self.kwargs)
\ No newline at end of file
