@@ -5,6 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 import contextlib
+import copy
 import json
 import os
 import random
@@ -13,6 +14,7 @@ import time
 from hashlib import sha256
 from shutil import move
 from threading import Thread
+from decentra_network.blockchain.block.block_main import Block
 
 from decentra_network.blockchain.block.change_transaction_fee import \
     ChangeTransactionFee
@@ -68,6 +70,7 @@ class server(Thread):
         custom_CONNECTED_NODES_PATH=None,
         custom_PENDING_TRANSACTIONS_PATH=None,
         time_control=None,
+        custom_id=None,
     ):
         Thread.__init__(self)
         self.running = True
@@ -126,17 +129,26 @@ class server(Thread):
 
         self.time_control = 10 if time_control is None else time_control
 
+        self.custom_id = custom_id
+
         if not test:
             self.__class__.Server = self
             self.start()
 
     def check_connected(self, host, port):
+        logger.info("New node")
+        logger.debug(f"self.clients: {self.clients}")
+        logger.debug(f"Port: {port}")
+        logger.debug(f"Host: {host}")
         for a_client in self.clients:
             if a_client.host == host and a_client.port == port:
+                logger.warning("Already connected")
                 return True
+        logger.info("New connection")
         return False
 
     def run(self):
+        logger.info("Server started and listen new connections")
         self.sock.settimeout(10.0)
         while self.running:
             with contextlib.suppress(socket.timeout):
@@ -144,11 +156,18 @@ class server(Thread):
                 logger.info(
                     f"NODE:{self.host}:{self.port} New connection: {addr}")
                 data = conn.recv(1024)
-                conn.send(server.id.encode("utf-8"))
+                the_id = server.id if self.custom_id is None else self.custom_id
+                conn.send(the_id.encode("utf-8"))
                 client_id = data.decode("utf-8")
                 if Unl.node_is_unl(client_id):
+
+                    logger.info(f"Added node: {client_id}")
                     self.clients.append(client(conn, addr, client_id, self))
                     self.save_connected_node(addr[0], addr[1], client_id)
+                else:
+                    logger.info(
+                        f"This connection want dont accepted because its not unl: {client_id}"
+                    )
             time.sleep(0.01)
 
     def stop(self):
@@ -193,7 +212,8 @@ class server(Thread):
         if len(json.dumps(data).encode("utf-8")) < 6525:
             data["buffer"] = "0" * (
                 (6525 - len(json.dumps(data).encode("utf-8"))) - 14)
-        node.socket.sendall(json.dumps(data).encode("utf-8"))
+        with contextlib.suppress(socket.timeout):
+            node.socket.sendall(json.dumps(data).encode("utf-8"))
         with contextlib.suppress(KeyError):
             del data["buffer"]
         time.sleep(0.02)
@@ -213,25 +233,36 @@ class server(Thread):
 
     def check_message(self, data):
         if "id" not in data:
+            logger.debug("No id")
             return False
         if "signature" not in data:
+            logger.debug("No signature")
             return False
         if "timestamp" not in data:
+            logger.debug("No timestamp")
             return False
-        the_control = time.time() - float(data["timestamp"])
-        if the_control > self.time_control:
-            return False
+        #the_control = time.time() - float(data["timestamp"])
+        #if the_control > self.time_control:
+        #    logger.debug("Time control is not true")
+        #    return False
         # remove sign from data
         sign = data["signature"]
         del data["signature"]
         message = str(data)
         data["signature"] = sign
-        return Ecdsa.verify(
+
+        signature_verify = Ecdsa.verify(
             message,
             Signature.fromBase64(sign),
             PublicKey.fromPem(data["id"]),
         )
 
+        if not signature_verify:
+            logger.debug("Signature not valid")
+            return False
+
+        return True
+
     def connect(self, host, port):
         connected = self.check_connected(host=host, port=port)
         if not connected:
@@ -351,7 +382,7 @@ class server(Thread):
         the_node = node if node is not None else random.choice(self.clients)
         self.send_client(the_node, {"action": "sendmefullblock"})
 
-    def send_my_block(self, block):
+    def send_my_block(self, block: Block):
         system = block
 
         new_list = []
@@ -365,6 +396,7 @@ class server(Thread):
         data = {
             "action": "myblock",
             "transaction": new_list,
+            "sequence_number": system.sequence_number,
         }
         self.send(data)
 
@@ -374,15 +406,34 @@ class server(Thread):
         data = {
             "action": "myblockhash",
             "hash": system.hash,
+            "previous_hash": system.previous_hash,
+            "sequence_number": system.sequence_number,
         }
 
         self.send(data)
 
-    def get_candidate_block(self, data, node):
+    def get_candidate_block(self, data, node: client):
+        if node.candidate_block is None:
+            node.candidate_block = data
+            return
+        if data["sequence_number"] > node.candidate_block["sequence_number"]:
+            if len(node.candidate_block_history) >= 5:
+                node.candidate_block_history.pop(0)
+
+            node.candidate_block_history.append(copy.copy(node.candidate_block))
 
         node.candidate_block = data
 
-    def get_candidate_block_hash(self, data, node):
+    def get_candidate_block_hash(self, data, node: client):
+        if node.candidate_block_hash is None:
+            node.candidate_block_hash = data
+            return        
+        if data["sequence_number"] > node.candidate_block_hash["sequence_number"]:
+            if len(node.candidate_block_hash_history) >= 5:
+                node.candidate_block_hash_history.pop(0)
+
+            node.candidate_block_hash_history.append(copy.copy(node.candidate_block_hash))
+
         data["sender"] = node.id
         node.candidate_block_hash = data
 
@@ -509,7 +560,7 @@ class server(Thread):
                     consensus_trigger
                 from decentra_network.lib.perpetualtimer import perpetualTimer
 
-                system = GetBlock(custom_TEMP_BLOCK_PATH=self.TEMP_BLOCK_PATH)
+                system = GetBlock(custom_TEMP_BLOCK_PATH=self.TEMP_BLOCK_PATH, get_normal_block=True)
 
                 ChangeTransactionFee(system)
 
@@ -603,7 +654,7 @@ class server(Thread):
 
         data = {
             "action": "transactionrequest",
-            "sequance_number": tx.sequance_number,
+            "sequence_number": tx.sequence_number,
             "txsignature": tx.signature,
             "fromUser": tx.fromUser,
             "to_user": tx.toUser,
@@ -621,7 +672,7 @@ class server(Thread):
     def get_transaction(self, data, node):
         block = GetBlock(custom_TEMP_BLOCK_PATH=self.TEMP_BLOCK_PATH)
         the_transaction = Transaction(
-            data["sequance_number"],
+            data["sequence_number"],
             data["txsignature"],
             data["fromUser"],
             data["to_user"],
@@ -668,9 +719,9 @@ class server(Thread):
         Sends the block to the other nodes.
         """
         if node is None or sync:
-            self.send_full_chain(node=node)
             self.send_full_accounts(node=node)
             self.send_full_blockshash(node=node)
             self.send_full_blockshash_part(node=node)
+            self.send_full_chain(node=node)
         else:
             self.sync_clients.append(node)
